@@ -1,7 +1,8 @@
+# Deprecated
 from .buttons import (
     Buttons,
     UpButton,
     DownButton,
     SelectButton,
-    CancelButton
+    CancelButton,
 )
