@@ -1,6 +1,4 @@
 from gpiozero import Buzzer as gpiozero_Buzzer
-from gpiozero.pins.native import NativeFactory
-
 from pitop.core.mixins import (
     Stateful,
     Recreatable,
@@ -21,7 +19,7 @@ class Buzzer(Stateful, Recreatable, gpiozero_Buzzer):
 
         Stateful.__init__(self)
         Recreatable.__init__(self, {"port_name": port_name, "name": self.name})
-        gpiozero_Buzzer.__init__(self, get_pin_for_port(self._pma_port), pin_factory=NativeFactory())
+        gpiozero_Buzzer.__init__(self, get_pin_for_port(self._pma_port))
 
     @property
     def own_state(self):
